#
# spec file for package yarn
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yarn
Version:        1.22.22
Release:        1.4
Summary:        📦🐈 Fast, reliable, and secure dependency management
License:        BSD-2-Clause
URL:            https://github.com/yarnpkg/%{name}/releases
Source:         %{URL}/download/v%{version}/yarn-v%{version}.tar.gz
Requires:       nodejs >= 4.0
Requires:       sed
BuildArch:      noarch

%description
Fast: Yarn caches every package it has downloaded, so it never needs to
download the same package again. It also does almost everything concurrently to
maximize resource utilization. This means even faster installs.

Reliable: Using a detailed but concise lockfile format and a deterministic
algorithm for install operations, Yarn is able to guarantee that any
installation that works on one system will work exactly the same on another
system.

Secure: Yarn uses checksums to verify the integrity of every installed package
before its code is executed.

%prep
%autosetup -n %{name}-v%{version}

%build
rm bin/*.cmd
perl -p -i -e 's|%{_bindir}/env node|%{_bindir}/node|g' bin/* lib/*

%install
install -D -d -m 0755              %{buildroot}%{_datadir}/yarn/ %{buildroot}%{_bindir}
cp -av bin/ lib/ package.json      %{buildroot}%{_datadir}/yarn/
ln -s %{_datadir}/yarn/bin/yarn    %{buildroot}%{_bindir}/yarn
ln -s %{_datadir}/yarn/bin/yarnpkg %{buildroot}%{_bindir}/yarnpkg

%files
%doc README.md
%license LICENSE
%{_datadir}/yarn/
%{_bindir}/yarn
%{_bindir}/yarnpkg

%changelog
* Wed Jun 19 2024 Avindra Goolcharan <avindra@opensuse.org>
- update to 1.22.22:
  * Fix a hoisting issue when transitive dependencies themselves
    listed aliases as dependencies
  * Fix a punycode warning
* Sat Dec  2 2023 Gagah Pangeran <gagahpangeran29@gmail.com>
- update to 1.22.21:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.20
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.21
* Thu May 12 2022 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.19:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.19
* Fri Mar 25 2022 Manu Maier <mmanu84@outlook.de>
- update to 1.22.18:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.18
* Wed Oct 20 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.17:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.16
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.17
* Thu Sep 30 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.15:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.15
* Wed Sep 29 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.14:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.14
* Wed Sep 29 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.13:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.13
* Fri Jul 30 2021 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.11:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.11
* Fri Apr 23 2021 Dan Čermák <dcermak@suse.com>
- Add missing Requires: sed
- Run spec cleaner
* Wed Nov 11 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.22.10:
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.10
* Thu Aug 27 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.5
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.5
* Tue Apr 14 2020 Manuel Schnitzer <mschnitzer@suse.com>
- Remove nodejs from build requires
  Just the runtime dependency is needed.
* Mon Mar  9 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.4
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.3
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.4
* Sat Mar  7 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.2
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.2
* Fri Mar  6 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.1
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.1
* Thu Feb  6 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.22.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.22.0
* Wed Dec 11 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.21.1
  https://github.com/yarnpkg/yarn/releases/tag/v1.21.1
* Mon Dec  2 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.21.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.20.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.21.0
* Fri Nov 22 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.19.2
  https://github.com/yarnpkg/yarn/releases/tag/v1.19.2
* Tue Oct  8 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.19.1
  https://github.com/yarnpkg/yarn/releases/tag/v1.19.1
* Sun Sep 29 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.19.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.18.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.19.0
* Thu Sep 19 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.17.3
  https://github.com/yarnpkg/yarn/releases/tag/v1.17.0
  https://github.com/yarnpkg/yarn/releases/tag/v1.17.1
  https://github.com/yarnpkg/yarn/releases/tag/v1.17.2
  https://github.com/yarnpkg/yarn/releases/tag/v1.17.3
* Tue Apr 30 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.16.0
  - Retries downloading a package on `yarn install` when we get a ETIMEDOUT error.
    [#7163](https://github.com/yarnpkg/yarn/pull/7163) - [**Vincent Bailly**](https://github.com/VincentBailly)
  - Implements `yarn audit --level [severity]` flag to filter the audit command's output.
    [#6716](https://github.com/yarnpkg/yarn/pull/6716) - [**Rogério Vicente**](https://twitter.com/rogeriopvl)
  - Implements `yarn audit --groups group_name [group_name ...]`.
    [#6724](https://github.com/yarnpkg/yarn/pull/6724) - [**Tom Milligan**](https://github.com/tommilligan)
  - Exposes the script environment variables to `yarn create` spawned processes.
    [#7127](https://github.com/yarnpkg/yarn/pull/7127) - [**Eli Perelman**](https://github.com/eliperelman)
  - Prevents EPIPE errors from being printed.
    [#7194](https://github.com/yarnpkg/yarn/pull/7194) - [**Abhishek Reddy**](https://github.com/arbscht)
  - Adds support for the npm enterprise URLs when computing the offline mirror filenames.
    [#7200](https://github.com/yarnpkg/yarn/pull/7200) - [**John Millikin**](https://john-millikin.com)
  - Tweaks the lockfile parser logic to parse a few extra cases
    [#7210](https://github.com/yarnpkg/yarn/pull/7210) - [**Maël Nison**](https://twitter.com/arcanis)
* Tue Mar 19 2019 Marcus Rueckert <mrueckert@suse.de>
- initial package
